/*******************************************************************************
* File Name: Port15Pins.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Port15Pins.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 Port15Pins__PORT == 15 && ((Port15Pins__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: Port15Pins_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void Port15Pins_Write(uint8 value) 
{
    uint8 staticBits = (Port15Pins_DR & (uint8)(~Port15Pins_MASK));
    Port15Pins_DR = staticBits | ((uint8)(value << Port15Pins_SHIFT) & Port15Pins_MASK);
}


/*******************************************************************************
* Function Name: Port15Pins_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Port15Pins_DM_STRONG     Strong Drive 
*  Port15Pins_DM_OD_HI      Open Drain, Drives High 
*  Port15Pins_DM_OD_LO      Open Drain, Drives Low 
*  Port15Pins_DM_RES_UP     Resistive Pull Up 
*  Port15Pins_DM_RES_DWN    Resistive Pull Down 
*  Port15Pins_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Port15Pins_DM_DIG_HIZ    High Impedance Digital 
*  Port15Pins_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Port15Pins_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Port15Pins_0, mode);
	CyPins_SetPinDriveMode(Port15Pins_1, mode);
	CyPins_SetPinDriveMode(Port15Pins_2, mode);
	CyPins_SetPinDriveMode(Port15Pins_3, mode);
	CyPins_SetPinDriveMode(Port15Pins_4, mode);
	CyPins_SetPinDriveMode(Port15Pins_5, mode);
}


/*******************************************************************************
* Function Name: Port15Pins_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Port15Pins_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Port15Pins_Read(void) 
{
    return (Port15Pins_PS & Port15Pins_MASK) >> Port15Pins_SHIFT;
}


/*******************************************************************************
* Function Name: Port15Pins_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Port15Pins_ReadDataReg(void) 
{
    return (Port15Pins_DR & Port15Pins_MASK) >> Port15Pins_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Port15Pins_INTSTAT) 

    /*******************************************************************************
    * Function Name: Port15Pins_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Port15Pins_ClearInterrupt(void) 
    {
        return (Port15Pins_INTSTAT & Port15Pins_MASK) >> Port15Pins_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
