/*******************************************************************************
* File Name: Port6Pins.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Port6Pins.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 Port6Pins__PORT == 15 && ((Port6Pins__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: Port6Pins_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void Port6Pins_Write(uint8 value) 
{
    uint8 staticBits = (Port6Pins_DR & (uint8)(~Port6Pins_MASK));
    Port6Pins_DR = staticBits | ((uint8)(value << Port6Pins_SHIFT) & Port6Pins_MASK);
}


/*******************************************************************************
* Function Name: Port6Pins_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Port6Pins_DM_STRONG     Strong Drive 
*  Port6Pins_DM_OD_HI      Open Drain, Drives High 
*  Port6Pins_DM_OD_LO      Open Drain, Drives Low 
*  Port6Pins_DM_RES_UP     Resistive Pull Up 
*  Port6Pins_DM_RES_DWN    Resistive Pull Down 
*  Port6Pins_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Port6Pins_DM_DIG_HIZ    High Impedance Digital 
*  Port6Pins_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Port6Pins_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Port6Pins_0, mode);
	CyPins_SetPinDriveMode(Port6Pins_1, mode);
	CyPins_SetPinDriveMode(Port6Pins_2, mode);
	CyPins_SetPinDriveMode(Port6Pins_3, mode);
	CyPins_SetPinDriveMode(Port6Pins_4, mode);
	CyPins_SetPinDriveMode(Port6Pins_5, mode);
	CyPins_SetPinDriveMode(Port6Pins_6, mode);
	CyPins_SetPinDriveMode(Port6Pins_7, mode);
}


/*******************************************************************************
* Function Name: Port6Pins_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Port6Pins_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Port6Pins_Read(void) 
{
    return (Port6Pins_PS & Port6Pins_MASK) >> Port6Pins_SHIFT;
}


/*******************************************************************************
* Function Name: Port6Pins_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Port6Pins_ReadDataReg(void) 
{
    return (Port6Pins_DR & Port6Pins_MASK) >> Port6Pins_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Port6Pins_INTSTAT) 

    /*******************************************************************************
    * Function Name: Port6Pins_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Port6Pins_ClearInterrupt(void) 
    {
        return (Port6Pins_INTSTAT & Port6Pins_MASK) >> Port6Pins_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
